@@ -1,11 +1,12 @@
 package List::Objects::WithUtils::Array;
 {
-  $List::Objects::WithUtils::Array::VERSION = '0.001001';
+  $List::Objects::WithUtils::Array::VERSION = '0.002000';
 }
 use strictures 1;
 
 use Role::Tiny::With;
-with 'List::Objects::WithUtils::Role::Array';
+with 'List::Objects::WithUtils::Role::Array',
+     'List::Objects::WithUtils::Role::WithJunctions';
 
 use Exporter 'import';
 our @EXPORT = 'array';
@@ -28,10 +29,14 @@ List::Objects::WithUtils::Array - An array container class
 See L<List::Objects::WithUtils::Role::Array> for a description of available
 methods.
 
+This class also consumes L<List::Objects::WithUtils::Role::WithJunctions>.
+
 =head1 DESCRIPTION
 
 This class is a concrete implementation of
-L<List::Objects::WithUtils::Role::Array>. Methods are documented there.
+L<List::Objects::WithUtils::Role::Array>
+and L<List::Objects::WithUtils::Role::WithJunctions>. 
+Methods are documented there.
 
 =head2 array
 
